==> alfresco-governance-services-community-repo-25.1.2.5-sources.jar: org/alfresco/module/org_alfresco_module_rm/bulk/hold/HoldBulkMonitor.java <==
/*
 * #%L
 * Alfresco Records Management Module
 * %%
 * Copyright (C) 2005 - 2025 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software.
 * -
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail.  Otherwise, the software is
 * provided under the following open source license terms:
 * -
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * -
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * -
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.module.org_alfresco_module_rm.bulk.hold;

import java.util.List;

import org.alfresco.module.org_alfresco_module_rm.bulk.BulkMonitor;

/**
 * An interface for monitoring the progress of a bulk hold operation
 */
public interface HoldBulkMonitor extends BulkMonitor<HoldBulkStatus>
{
    /**
     * Get the bulk statuses with process details for a hold
     *
     * @param holdId the hold id
     * @return the bulk statuses with process details
     */
    List<HoldBulkStatusAndProcessDetails> getBulkStatusesWithProcessDetails(String holdId);

    /**
     * Get the bulk status with process details
     *
     * @param holdId       the hold id
     * @param bulkStatusId the bulk status id
     * @return the bulk status with process details
     */
    HoldBulkStatusAndProcessDetails getBulkStatusWithProcessDetails(String holdId, String bulkStatusId);
}

==> alfresco-governance-services-community-repo-25.3.0.61-sources.jar: org/alfresco/module/org_alfresco_module_rm/bulk/hold/HoldBulkMonitor.java <==
/*
 * #%L
 * Alfresco Records Management Module
 * %%
 * Copyright (C) 2005 - 2025 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software.
 * -
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail.  Otherwise, the software is
 * provided under the following open source license terms:
 * -
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * -
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * -
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.module.org_alfresco_module_rm.bulk.hold;

import java.util.List;

import org.alfresco.module.org_alfresco_module_rm.bulk.BulkMonitor;

/**
 * An interface for monitoring the progress of a bulk hold operation
 */
public interface HoldBulkMonitor extends BulkMonitor<HoldBulkStatus>
{
    /**
     * Get the bulk statuses with process details for a hold
     *
     * @param holdId
     *            the hold id
     * @return the bulk statuses with process details
     */
    List<HoldBulkStatusAndProcessDetails> getBulkStatusesWithProcessDetails(String holdId);

    /**
     * Get the bulk status with process details
     *
     * @param holdId
     *            the hold id
     * @param bulkStatusId
     *            the bulk status id
     * @return the bulk status with process details
     */
    HoldBulkStatusAndProcessDetails getBulkStatusWithProcessDetails(String holdId, String bulkStatusId);
}
